@@ -16,7 +16,8 @@ from .evaluator.general_evaluator import GeneralEvaluator
 
 class CIFAR(Dataset):
 
-    def __init__(self, root, train=True, transform=None, target_transform=None, top_k=(1, 5), is_cifar100=True):
+    def __init__(self, root, train=True, transform=None, target_transform=None, top_k=(1, 5),
+                 is_cifar100=True, keep_rgb=False):
         if is_cifar100:
             self.data_set = CIFAR100(root, train=train, download=True)
         else:
@@ -25,11 +26,12 @@ class CIFAR(Dataset):
         self.root = root
         self.transform = transform
         self.target_transform = target_transform
+        self.keep_rgb = keep_rgb
         self._update_evaluator(top_k)
 
     def __getitem__(self, index: int):
         image, target = self.data_set.__getitem__(index)
-        image = default_converter(image, rgb=False)
+        image = default_converter(image, rgb=self.keep_rgb)
 
         if self.transform is not None:
             image = self.transform(image)
