@@ -65,25 +65,38 @@ class BaseEvaluator(metaclass=ABCMeta):
         if len(self.total_targets_list) == 0:
             return None, None
 
-        result_str = '\ntotal({}) -'.format(len(self.total_targets_list))
+        img_length = len(self.total_targets_list)
+        result_str = '\ntotal({}) - '.format(img_length)
         topk_list, correct_topk_list = topk_accuracy(torch.stack(self.total_outputs_list),
                                                      torch.stack(self.total_targets_list),
                                                      top_k=self.top_k)
         acc_dict = dict()
         for i in range(len(self.top_k)):
             acc_dict[f"top{self.top_k[i]}"] = topk_list[i]
-            result_str += ' top{} acc({}): {:6.3f}'.format(self.top_k[i], correct_topk_list[i], topk_list[i])
+            result_str += 'top{} acc({}): {:6.3f}%\t'.format(self.top_k[i], correct_topk_list[i], topk_list[i])
+
+        num_len = len(f'({img_length})'.encode('utf-8'))
+        max_cls_len = 0
+        for cls_name in self.classes:
+            if len(cls_name.encode('utf-8')) > max_cls_len:
+                max_cls_len = len(cls_name.encode('utf-8'))
+        max_cls_len += num_len
 
         for idx in range(len(self.classes)):
             class_name = self.classes[idx].strip()
 
             key = str(idx)
             cate_outputs = self.cate_outputs_dict[key]
-            result_str += '\n{:<3}\t- {:<20}\t'.format(idx, class_name)
+            result_str += '\n{item1:<4} - {item2:<{length}}\t'.format(item1=idx,
+                                                                      item2=f'{class_name}({str(len(cate_outputs))})',
+                                                                      length=max_cls_len)
             if len(cate_outputs) == 0:
                 for i in range(len(self.top_k)):
                     acc_dict[f"top{self.top_k[i]}"] = 0.
-                    result_str += '\ttop{}(0): {:<5}'.format(self.top_k[i], "{:.2f}".format(0.))
+                    result_str += '{item1}: {item2:6.2f}%\t'.format(
+                        item1=f'top{self.top_k[i]}',
+                        item2=0.)
+
             else:
                 cate_outputs = torch.stack(self.cate_outputs_dict[key])
                 cate_targets = torch.stack(self.cate_targets_dict[key])
@@ -92,9 +105,10 @@ class BaseEvaluator(metaclass=ABCMeta):
 
                 for i in range(len(self.top_k)):
                     acc_dict[f"top{self.top_k[i]}"] = topk_list[i]
-                    result_str += '\ttop{}({}): {:<5}'.format(self.top_k[i],
-                                                              correct_topk_list[i],
-                                                              "{:.2f}".format(topk_list[i]))
+                    result_str += '{item1}: {item2:6.2f}%\t'.format(
+                        item1=f'top{self.top_k[i]}',
+                        item2=topk_list[i]
+                    )
         result_str += '\n'
 
         return result_str, acc_dict
